@@ -1,9 +1,9 @@
 # borders format ----
 
 #' @export
-#' @title Cell borders update
+#' @title Set cell borders
 #' @description change borders of selected rows and columns of a flextable.
-#' This function is not to be used by end user (it requires careful
+#' This function is **not to be used by end user** (it requires careful
 #' settings to avoid overlapping borders) but only for programming purposes.
 #'
 #' If you need to add borders, use instead other functions:
@@ -29,10 +29,7 @@
 #' [surround()].
 #' @note
 #' pdf and pptx outputs do not support `border()` usage.
-#' @param x a flextable object
-#' @param i rows selection
-#' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
+#' @inheritParams args_selectors_with_all
 #' @param border border (shortcut for top, bottom, left and right)
 #' @param border.top border top
 #' @param border.bottom border bottom
@@ -44,29 +41,50 @@
 #' ftab <- border(ftab, border.top = fp_border(color = "orange"))
 #' ftab
 #' @keywords internal
-border <- function(x, i = NULL, j = NULL, border = NULL,
-                   border.top = NULL, border.bottom = NULL,
-                   border.left = NULL, border.right = NULL,
-                   part = "body") {
+border <- function(
+  x,
+  i = NULL,
+  j = NULL,
+  border = NULL,
+  border.top = NULL,
+  border.bottom = NULL,
+  border.left = NULL,
+  border.right = NULL,
+  part = "body"
+) {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "border()"))
   }
 
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (!is.null(border)) {
-    if (is.null(border.top)) border.top <- border
-    if (is.null(border.bottom)) border.bottom <- border
-    if (is.null(border.left)) border.left <- border
+    if (is.null(border.top)) {
+      border.top <- border
+    }
+    if (is.null(border.bottom)) {
+      border.bottom <- border
+    }
+    if (is.null(border.left)) {
+      border.left <- border
+    }
     if (is.null(border.right)) border.right <- border
   }
 
   if (part == "all") {
     for (p in c("header", "body", "footer")) {
       x <- border(
-        x = x, i = i, j = j,
-        border.top = border.top, border.bottom = border.bottom,
-        border.left = border.left, border.right = border.right,
+        x = x,
+        i = i,
+        j = j,
+        border.top = border.top,
+        border.bottom = border.bottom,
+        border.left = border.left,
+        border.right = border.right,
         part = p
       )
     }
@@ -87,19 +105,46 @@ border <- function(x, i = NULL, j = NULL, border = NULL,
     x[[part]]$styles$cells[["border.width.top"]]$data[i, j] <- border.top$width
   }
   if (!is.null(border.bottom)) {
-    x[[part]]$styles$cells[["border.style.bottom"]]$data[i, j] <- border.bottom$style
-    x[[part]]$styles$cells[["border.color.bottom"]]$data[i, j] <- border.bottom$color
-    x[[part]]$styles$cells[["border.width.bottom"]]$data[i, j] <- border.bottom$width
+    x[[part]]$styles$cells[["border.style.bottom"]]$data[
+      i,
+      j
+    ] <- border.bottom$style
+    x[[part]]$styles$cells[["border.color.bottom"]]$data[
+      i,
+      j
+    ] <- border.bottom$color
+    x[[part]]$styles$cells[["border.width.bottom"]]$data[
+      i,
+      j
+    ] <- border.bottom$width
   }
   if (!is.null(border.left)) {
-    x[[part]]$styles$cells[["border.style.left"]]$data[i, j] <- border.left$style
-    x[[part]]$styles$cells[["border.color.left"]]$data[i, j] <- border.left$color
-    x[[part]]$styles$cells[["border.width.left"]]$data[i, j] <- border.left$width
+    x[[part]]$styles$cells[["border.style.left"]]$data[
+      i,
+      j
+    ] <- border.left$style
+    x[[part]]$styles$cells[["border.color.left"]]$data[
+      i,
+      j
+    ] <- border.left$color
+    x[[part]]$styles$cells[["border.width.left"]]$data[
+      i,
+      j
+    ] <- border.left$width
   }
   if (!is.null(border.right)) {
-    x[[part]]$styles$cells[["border.style.right"]]$data[i, j] <- border.right$style
-    x[[part]]$styles$cells[["border.color.right"]]$data[i, j] <- border.right$color
-    x[[part]]$styles$cells[["border.width.right"]]$data[i, j] <- border.right$width
+    x[[part]]$styles$cells[["border.style.right"]]$data[
+      i,
+      j
+    ] <- border.right$style
+    x[[part]]$styles$cells[["border.color.right"]]$data[
+      i,
+      j
+    ] <- border.right$color
+    x[[part]]$styles$cells[["border.width.right"]]$data[
+      i,
+      j
+    ] <- border.right$width
   }
 
   x
@@ -108,7 +153,7 @@ border <- function(x, i = NULL, j = NULL, border = NULL,
 
 #' @title Remove borders
 #' @description The function is deleting all borders of the flextable object.
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @examples
 #' dat <- iris[c(1:5, 51:55, 101:105), ]
 #' ft_1 <- flextable(dat)
@@ -122,7 +167,10 @@ border <- function(x, i = NULL, j = NULL, border = NULL,
 #' @family borders management
 border_remove <- function(x) {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "border_remove()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "border_remove()"
+    ))
   }
   x <- border(x = x, border = fp_border(width = 0), part = "all")
   x
@@ -131,8 +179,7 @@ border_remove <- function(x) {
 #' @title Set outer borders
 #' @description The function is applying a border to outer cells of one
 #' or all parts of a flextable.
-#' @param x a flextable object
-#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
+#' @inheritParams args_x_part
 #' @param border border properties defined by a call to [officer::fp_border()]
 #' @export
 #' @examples
@@ -149,10 +196,17 @@ border_remove <- function(x) {
 #' @family borders management
 border_outer <- function(x, border = NULL, part = "all") {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "border_outer()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "border_outer()"
+    ))
   }
 
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -177,7 +231,7 @@ border_outer <- function(x, border = NULL, part = "all") {
 }
 
 #' @export
-#' @title Set inner borders
+#' @title Set inner horizontal borders
 #' @description The function is applying a border to inner content of one
 #' or all parts of a flextable.
 #' @inheritParams border_outer
@@ -195,9 +249,16 @@ border_outer <- function(x, border = NULL, part = "all") {
 #' @family borders management
 border_inner_h <- function(x, border = NULL, part = "body") {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "border_inner_h()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "border_inner_h()"
+    ))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -220,7 +281,7 @@ border_inner_h <- function(x, border = NULL, part = "body") {
 }
 
 #' @export
-#' @title Set vertical inner borders
+#' @title Set inner vertical borders
 #' @description The function is applying a vertical border to inner content of one
 #' or all parts of a flextable.
 #' @inheritParams border_outer
@@ -238,9 +299,16 @@ border_inner_h <- function(x, border = NULL, part = "body") {
 #' @family borders management
 border_inner_v <- function(x, border = NULL, part = "all") {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "border_inner_v()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "border_inner_v()"
+    ))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -263,7 +331,7 @@ border_inner_v <- function(x, border = NULL, part = "all") {
 }
 
 #' @export
-#' @title Set vertical & horizontal inner borders
+#' @title Set all inner borders
 #' @description The function is applying a vertical and horizontal borders to inner content of one
 #' or all parts of a flextable.
 #' @inheritParams border_outer
@@ -281,9 +349,16 @@ border_inner_v <- function(x, border = NULL, part = "all") {
 #' @family borders management
 border_inner <- function(x, border = NULL, part = "all") {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "border_inner()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "border_inner()"
+    ))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -313,13 +388,24 @@ border_inner <- function(x, border = NULL, part = "all") {
 }
 
 #' @export
-#' @title Set horizontal borders
-#' @description The function is applying an horizontal border to inner
-#' content of one or all parts of a flextable. The lines are the
-#' bottom borders of selected cells.
-#' @inheritParams border_outer
-#' @param i rows selection
-#' @param j columns selection
+#' @title Set horizontal borders below selected rows
+#' @description
+#' `hline()` draws a horizontal line **below** each selected row by
+#' setting the bottom border of cells at row `i` (and the top border
+#' of cells at row `i + 1` so that the line renders consistently
+#' across output formats).
+#'
+#' Use the `i` selector to target specific rows (e.g. a formula
+#' such as `~ before(col, "Total")`). When `i` is `NULL` (the
+#' default) the border is added below every row, which produces
+#' a full grid of inner horizontal lines.
+#'
+#' For the **outer** edges of the table, use [hline_top()] and
+#' [hline_bottom()] instead; those always target the very first
+#' or very last row of a part.
+#' @inheritParams args_selectors_with_all
+#' @param border border properties defined by a call to
+#' [officer::fp_border()]
 #' @examples
 #' library(officer)
 #' std_border <- fp_border(color = "gray")
@@ -327,7 +413,7 @@ border_inner <- function(x, border = NULL, part = "all") {
 #' ft <- flextable(head(iris))
 #' ft <- border_remove(x = ft)
 #'
-#' # add horizontal borders
+#' # add horizontal borders below every row
 #' ft <- hline(ft, part = "all", border = std_border)
 #' ft
 #' @family borders management
@@ -335,7 +421,11 @@ hline <- function(x, i = NULL, j = NULL, border = NULL, part = "body") {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "hline()"))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -344,7 +434,9 @@ hline <- function(x, i = NULL, j = NULL, border = NULL, part = "body") {
   if (part == "all") {
     for (p in c("header", "body", "footer")) {
       x <- hline(
-        x = x, i = i, j = j,
+        x = x,
+        i = i,
+        j = j,
         border = border,
         part = p
       )
@@ -371,12 +463,21 @@ hline <- function(x, i = NULL, j = NULL, border = NULL, part = "body") {
 }
 
 #' @export
-#' @title Set top horizontal border
-#' @description The function is applying an horizontal border to the
-#' top of one or all parts of a flextable. The line is the
-#' top border of selected parts.
-#' @inheritParams border_outer
-#' @param j columns selection
+#' @title Set the top border of a table part
+#' @description
+#' `hline_top()` draws a horizontal line at the **very top** of a
+#' table part. It does not accept a row selector `i` because it
+#' always targets the first row.
+#'
+#' When the part above exists (e.g. header above body), the line
+#' is stored as the bottom border of that adjacent part so that
+#' it renders seamlessly.
+#'
+#' Unlike [hline()], which adds inner lines below arbitrary rows,
+#' `hline_top()` is meant for the outer top edge of a part.
+#' @inheritParams args_x_j_part
+#' @param border border properties defined by a call to
+#' [officer::fp_border()]
 #' @examples
 #' library(officer)
 #' big_border <- fp_border(color = "orange", width = 3)
@@ -384,15 +485,22 @@ hline <- function(x, i = NULL, j = NULL, border = NULL, part = "body") {
 #' ft <- flextable(head(iris))
 #' ft <- border_remove(x = ft)
 #'
-#' # add horizontal border on top
+#' # add a thick line on top of each part
 #' ft <- hline_top(ft, part = "all", border = big_border)
 #' ft
 #' @family borders management
 hline_top <- function(x, j = NULL, border = NULL, part = "body") {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "hline_top()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "hline_top()"
+    ))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -412,9 +520,21 @@ hline_top <- function(x, j = NULL, border = NULL, part = "body") {
   j <- get_columns_id(x[[part]], j)
 
   if (part %in% "body" && nrow_part(x, "header") > 0) {
-    x <- border(x, i = nrow_part(x, "header"), j = j, border.bottom = border, part = "header")
+    x <- border(
+      x,
+      i = nrow_part(x, "header"),
+      j = j,
+      border.bottom = border,
+      part = "header"
+    )
   } else if (part %in% "footer" && nrow_part(x, "body") > 0) {
-    x <- border(x, i = nrow_part(x, "body"), j = j, border.bottom = border, part = "body")
+    x <- border(
+      x,
+      i = nrow_part(x, "body"),
+      j = j,
+      border.bottom = border,
+      part = "body"
+    )
   } else {
     x <- border(x, i = 1, j = j, border.top = border, part = part)
   }
@@ -423,12 +543,15 @@ hline_top <- function(x, j = NULL, border = NULL, part = "body") {
 }
 
 #' @export
-#' @title Set bottom horizontal border
-#' @description The function is applying an horizontal border to the
-#' bottom of one or all parts of a flextable. The line is the
-#' bottom border of selected parts.
-#' @inheritParams border_outer
-#' @param j columns selection
+#' @title Set the bottom border of a table part
+#' @description
+#' `hline_bottom()` draws a horizontal line at the **very bottom**
+#' of a table part. It does not accept a row selector `i` because
+#' it always targets the last row.
+#'
+#' Unlike [hline()], which adds inner lines below arbitrary rows,
+#' `hline_bottom()` is meant for the outer bottom edge of a part.
+#' @inheritParams hline_top
 #' @examples
 #' library(officer)
 #' big_border <- fp_border(color = "orange", width = 3)
@@ -436,15 +559,22 @@ hline_top <- function(x, j = NULL, border = NULL, part = "body") {
 #' ft <- flextable(head(iris))
 #' ft <- border_remove(x = ft)
 #'
-#' # add/replace horizontal border on bottom
+#' # add a thick line at the bottom of the body
 #' ft <- hline_bottom(ft, part = "body", border = big_border)
 #' ft
 #' @family borders management
 hline_bottom <- function(x, j = NULL, border = NULL, part = "body") {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "hline_bottom()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "hline_bottom()"
+    ))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -462,16 +592,34 @@ hline_bottom <- function(x, j = NULL, border = NULL, part = "body") {
   }
 
   j <- get_columns_id(x[[part]], j)
-  x <- border(x, i = nrow_part(x, part), j = j, border.bottom = border, part = part)
+  x <- border(
+    x,
+    i = nrow_part(x, part),
+    j = j,
+    border.bottom = border,
+    part = part
+  )
   x
 }
 
 #' @export
-#' @title Set vertical borders
-#' @description The function is applying vertical borders to inner
-#' content of one or all parts of a flextable. The lines are the
-#' right borders of selected cells.
-#' @inheritParams hline
+#' @title Set vertical borders to the right of selected columns
+#' @description
+#' `vline()` draws a vertical line to the **right** of each
+#' selected column by setting the right border of cells at
+#' column `j` (and the left border of cells at column `j + 1`
+#' so that the line renders consistently across output formats).
+#'
+#' Use the `j` selector to target specific columns. When `j` is
+#' `NULL` (the default) the border is added to the right of every
+#' column, producing a full grid of inner vertical lines.
+#'
+#' For the **outer** edges of the table, use [vline_left()] and
+#' [vline_right()] instead; those always target the very first
+#' or very last column.
+#' @inheritParams args_selectors_with_all
+#' @param border border properties defined by a call to
+#' [officer::fp_border()]
 #' @examples
 #' library(officer)
 #' std_border <- fp_border(color = "orange")
@@ -479,7 +627,7 @@ hline_bottom <- function(x, j = NULL, border = NULL, part = "body") {
 #' ft <- flextable(head(iris))
 #' ft <- border_remove(x = ft)
 #'
-#' # add vertical borders
+#' # add vertical borders to the right of every column
 #' ft <- vline(ft, border = std_border)
 #' ft
 #' @family borders management
@@ -487,7 +635,11 @@ vline <- function(x, i = NULL, j = NULL, border = NULL, part = "all") {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "vline()"))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -516,12 +668,22 @@ vline <- function(x, i = NULL, j = NULL, border = NULL, part = "all") {
 }
 
 #' @export
-#' @title Set flextable left vertical borders
-#' @description The function is applying vertical borders to the
-#' left side of one or all parts of a flextable. The line is the
-#' left border of selected cells of the first column.
-#' @inheritParams border_outer
-#' @param i rows selection
+#' @title Set the left border of the table
+#' @description
+#' `vline_left()` draws a vertical line along the **left edge**
+#' of the table by setting the left border of the first column.
+#' It does not accept a column selector `j` because it always
+#' targets column 1.
+#'
+#' An optional row selector `i` lets you restrict the line to
+#' specific rows (e.g. only the body, or only certain rows).
+#'
+#' Unlike [vline()], which adds inner lines to the right of
+#' arbitrary columns, `vline_left()` is meant for the outer
+#' left edge of the table.
+#' @inheritParams args_x_i_part
+#' @param border border properties defined by a call to
+#' [officer::fp_border()]
 #' @examples
 #' library(officer)
 #' std_border <- fp_border(color = "orange")
@@ -529,15 +691,22 @@ vline <- function(x, i = NULL, j = NULL, border = NULL, part = "all") {
 #' ft <- flextable(head(iris))
 #' ft <- border_remove(x = ft)
 #'
-#' # add vertical border on the left side of the table
+#' # add a border on the left edge of the table
 #' ft <- vline_left(ft, border = std_border)
 #' ft
 #' @family borders management
 vline_left <- function(x, i = NULL, border = NULL, part = "all") {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "vline_left()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "vline_left()"
+    ))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -559,10 +728,19 @@ vline_left <- function(x, i = NULL, border = NULL, part = "all") {
 }
 
 #' @export
-#' @title Set flextable right vertical borders
-#' @description The function is applying vertical borders to the
-#' right side of one or all parts of a flextable. The line is the
-#' right border of selected cells of the last column.
+#' @title Set the right border of the table
+#' @description
+#' `vline_right()` draws a vertical line along the **right edge**
+#' of the table by setting the right border of the last column.
+#' It does not accept a column selector `j` because it always
+#' targets the last column.
+#'
+#' An optional row selector `i` lets you restrict the line to
+#' specific rows.
+#'
+#' Unlike [vline()], which adds inner lines to the right of
+#' arbitrary columns, `vline_right()` is meant for the outer
+#' right edge of the table.
 #' @inheritParams vline_left
 #' @examples
 #' library(officer)
@@ -571,15 +749,22 @@ vline_left <- function(x, i = NULL, border = NULL, part = "all") {
 #' ft <- flextable(head(iris))
 #' ft <- border_remove(x = ft)
 #'
-#' # add vertical border on the left side of the table
+#' # add a border on the right edge of the table
 #' ft <- vline_right(ft, border = std_border)
 #' ft
 #' @family borders management
 vline_right <- function(x, i = NULL, border = NULL, part = "all") {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "vline_right()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "vline_right()"
+    ))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (is.null(border)) {
     border <- fp_border(color = flextable_global$defaults$border.color)
@@ -596,16 +781,23 @@ vline_right <- function(x, i = NULL, border = NULL, part = "all") {
     return(x)
   }
 
-  x <- border(x, j = length(x$col_keys), i = i, border.right = border, part = part)
+  x <- border(
+    x,
+    j = length(x$col_keys),
+    i = i,
+    border.right = border,
+    part = part
+  )
   x
 }
 
 
-
 #' @export
-#' @title Is an element before a match with entries
-#' @description return a logical vector of the same length as x, indicating
-#' if elements are located before a set of entries to match or not.
+#' @title Detect rows before a given value
+#' @description Returns a logical vector indicating which elements
+#' of `x` appear before the first occurrence of any of the
+#' `entries` values. Useful as a row selector in [hline()] to
+#' insert a border above a summary row such as `"Total"`.
 #' @param x an atomic vector of values to be tested
 #' @param entries a sequence of items to be searched in `x`.
 #' @seealso [hline()]
@@ -648,8 +840,10 @@ before <- function(x, entries) {
 }
 
 #' @export
-#' @title Set borders for a selection of cells
-#' @description Highlight specific cells with borders.
+#' @title Surround cells with borders
+#' @description
+#' `surround()` draws borders around specific cells, highlighting
+#' them individually.
 #'
 #' To set borders for the whole table, use [border_outer()],
 #' [border_inner_h()] and [border_inner_v()].
@@ -701,28 +895,52 @@ before <- function(x, entries) {
 #' # print(ft, preview = "docx")
 #' # print(ft, preview = "pdf")
 #' # print(ft, preview = "html")
-surround <- function(x, i = NULL, j = NULL, border = NULL,
-                     border.top = NULL, border.bottom = NULL,
-                     border.left = NULL, border.right = NULL,
-                     part = "body") {
+surround <- function(
+  x,
+  i = NULL,
+  j = NULL,
+  border = NULL,
+  border.top = NULL,
+  border.bottom = NULL,
+  border.left = NULL,
+  border.right = NULL,
+  part = "body"
+) {
   if (!inherits(x, "flextable")) {
-    stop(sprintf("Function `%s` supports only flextable objects.", "surround()"))
+    stop(sprintf(
+      "Function `%s` supports only flextable objects.",
+      "surround()"
+    ))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
+  part <- match.arg(
+    part,
+    c("all", "body", "header", "footer"),
+    several.ok = FALSE
+  )
 
   if (!is.null(border)) {
-    if (is.null(border.top)) border.top <- border
-    if (is.null(border.bottom)) border.bottom <- border
-    if (is.null(border.left)) border.left <- border
+    if (is.null(border.top)) {
+      border.top <- border
+    }
+    if (is.null(border.bottom)) {
+      border.bottom <- border
+    }
+    if (is.null(border.left)) {
+      border.left <- border
+    }
     if (is.null(border.right)) border.right <- border
   }
 
   if (part == "all") {
     for (p in c("header", "body", "footer")) {
       x <- surround(
-        x = x, i = i, j = j,
-        border.top = border.top, border.bottom = border.bottom,
-        border.left = border.left, border.right = border.right,
+        x = x,
+        i = i,
+        j = j,
+        border.top = border.top,
+        border.bottom = border.bottom,
+        border.left = border.left,
+        border.right = border.right,
         part = p
       )
     }
