@@ -1,34 +1,38 @@
-
 # flextable grob ----------------------------------------------------------
 
 #' @export
-#' @title Convert a flextable to a grid grob object
-#' @description It uses Grid Graphics (package `grid`) to Convert a flextable
-#' into a grob object with scaling and text wrapping capabilities.
+#' @title Render a flextable as a graphic object
+#' @description
+#' `gen_grob()` converts a flextable into a Grid Graphics
+#' object (`grob`) that can be drawn on any R graphic device.
+#' This is the function behind [save_as_image()] and the
+#' patchwork integration ([wrap_flextable()]).
 #'
-#' This method can be used to insert a flextable inside a `ggplot2` plot,
-#' it can also be used with package 'patchwork' or 'cowplot' to combine
-#' ggplots and flextables into the same graphic.
+#' Typical uses:
+#' * embed a flextable in a `ggplot2` plot (via
+#'   [wrap_flextable()] or cowplot)
+#' * export a flextable as a PNG or SVG image (via
+#'   [save_as_image()])
 #'
-#' User can vary the size of the elements according to the size of the graphic window. The text
-#' behavior is controllable, user can decide to make the paragraphs (texts and images)
-#' distribute themselves correctly in the available space of the cell. It is possible
-#' to define resizing options, for example by using only the width, or by distributing
-#' the content so that it occupies the whole graphic space. It is also possible to
-#' freeze or not the size of the columns.
+#' Text wrapping and scaling are supported. The `fit`
+#' argument controls how the table adapts to the available
+#' space (fixed size, auto-fit width, or fill the device).
 #'
-#' It is not recommended to use this function for
-#' large tables because the calculations can be long.
+#' Not recommended for very large tables because the
+#' grid calculations can be slow.
 #'
-#' Limitations: equations (see [as_equation()]) and hyperlinks (see [hyperlink_ftext()])
-#' will not be displayed.
+#' Limitations: equations ([as_equation()]) and hyperlinks
+#' ([officer::hyperlink_ftext()]) are not rendered.
 #'
+#' Use a 'ragg', 'svglite' or 'ggiraph' device for correct
+#' rendering.
+#' @inheritSection save_as_image caption
 #' @section size:
 #'
 #' The size of the flextable can be known by using the method
 #' \link[=dim.flextableGrob]{dim} on the grob.
 #'
-#' @param x A flextable object
+#' @inheritParams args_x_only
 #'
 #' @param fit Determines the fitting/scaling of the grob on its parent viewport.
 #' One of `auto`, `width`, `fixed`, `TRUE`, `FALSE`:
@@ -84,29 +88,40 @@
 #'
 #' @return a grob (gTree) object made with package `grid`
 #' @examples
-#' ft <- flextable(head(mtcars))
-#' ft <- autofit(ft)
-#' gr <- gen_grob(ft)
-#' if (interactive()) plot(gr)
+#' \dontshow{
+#' data.table::setDTthreads(1)
+#' }
+#' library(ragg)
+#' library(gdtools)
+#' register_liberationsans()
 #'
-#' # get the size
-#' dims <- dim(gr)
-#' dims
-#' # svglite::svglite(filename = "hello-grid-graphics.svg",
-#' #   width = dims$width + .1,
-#' #   height = dims$height + .1)
-#' # gr <- gen_grob(ft, scaling = "fixed", fit = "fixed", just = "center")
-#' # plot(gr)
-#' # dev.off()
+#' set_flextable_defaults(font.family = "Liberation Sans")
+#'
+#' ft <- flextable(head(mtcars))
+#' gr <- gen_grob(ft)
+#' \dontshow{
+#' cap <- ragg::agg_capture(width = 7, height = 4, units = "in", res = 150)
+#' grDevices::dev.control("enable")
+#' }
+#' plot(gr)
+#' \dontshow{
+#' raster <- cap()
+#' dev.off()
+#' plot(as.raster(raster))
+#' }
 #' @family flextable print function
 #' @importFrom grid gTree
 gen_grob <- function(x,
-                    ...,
-                    fit = c("auto", "width", "fixed"),
-                    scaling = c("min", "full", "fixed"),
-                    wrapping = TRUE,
-                    autowidths = TRUE,
-                    just = NULL) {
+                     ...,
+                     fit = c("auto", "width", "fixed"),
+                     scaling = c("min", "full", "fixed"),
+                     wrapping = TRUE,
+                     autowidths = TRUE,
+                     just = NULL) {
+
+  x <- flextable_global$defaults$post_process_all(x)
+  x <- fix_border_issues(x)
+
   dots <- list(...)
   debug <- isTRUE(dots$debug)
   if (identical(fit, TRUE)) fit <- "auto"
@@ -336,6 +351,32 @@ makeContext.flextableGrob <- function(x) {
     # recalculate the heights
     heights <- calc_grob_heights(x, dat, params$dims)
     table_height <- sum(heights)
+
+    # flex_body: redistribute body row heights to fill the panel
+    if (isTRUE(params$flex_body)) {
+      n_h <- params$n_header_rows
+      n_b <- params$n_body_rows
+      n_f <- params$n_footer_rows
+      header_h <- if (n_h > 0) sum(heights[seq_len(n_h)]) else 0
+      footer_h <- if (n_f > 0) sum(heights[seq.int(n_h + n_b + 1L, length(heights))]) else 0
+      body_h <- norm_height - header_h - footer_h
+      if (body_h > 0 && n_b > 0) {
+        heights[seq.int(n_h + 1L, n_h + n_b)] <- body_h / n_b
+        table_height <- sum(heights)
+      }
+    }
+
+    # flex_cols: redistribute data column widths to fill the panel
+    if (isTRUE(params$flex_cols)) {
+      n_rh <- params$n_row_header_cols
+      n_dc <- params$n_data_cols
+      rh_w <- if (n_rh > 0) sum(widths[seq_len(n_rh)]) else 0
+      data_w <- norm_width - rh_w
+      if (data_w > 0 && n_dc > 0) {
+        widths[seq.int(n_rh + 1L, n_rh + n_dc)] <- data_w / n_dc
+        table_width <- sum(widths)
+      }
+    }
   }
 
   # create viewport
@@ -471,13 +512,13 @@ arrange_contents_grob <- function(x,
         params$paddingy) * height_factor
     }
 
-    child_count <- seq_index <- width <- NULL
+    child_count <- .chunk_index <- width <- NULL
     if (params$wrapping) {
       filtered <- c(
         unlist(dat[child_count > 0 & width * cex <= max_width, "children_index"]),
-        unlist(dat[child_count > 0 & width * cex > max_width, "seq_index"])
+        unlist(dat[child_count > 0 & width * cex > max_width, ".chunk_index"])
       )
-      dat <- dat[!seq_index %in% filtered, , drop = FALSE]
+      dat <- dat[!.chunk_index %in% filtered, , drop = FALSE]
     }
     n <- nrow(dat)
     if (n > 1) {
@@ -590,7 +631,7 @@ arrange_contents_grob <- function(x,
   }
 
   make_col_grob <- function(col_index, chunk_index,
-                            txt_data, from_seq_index, to_seq_index,
+                            txt_data, from_.chunk_index, to_.chunk_index,
                             width, height) {
     gr <- x$ftgrobs[[chunk_index]]
     params <- gr$ftpar
@@ -602,7 +643,7 @@ arrange_contents_grob <- function(x,
         is_bold = params$is_bold,
         is_italic = params$is_italic
       )
-      gr$name <- paste(gr$name, "seq", from_seq_index, "to", to_seq_index, sep = "_")
+      gr$name <- paste(gr$name, "seq", from_.chunk_index, "to", to_.chunk_index, sep = "_")
     }
     gr$vp <- viewport(
       layout.pos.row = 1,
@@ -623,8 +664,8 @@ arrange_contents_grob <- function(x,
   if (nrow(dat) > 1) {
     # group data by row, column and chunk
     col_dat <- dat[, list(
-      from = min(.SD$seq_index),
-      to = max(.SD$seq_index),
+      from = min(.SD$.chunk_index),
+      to = max(.SD$.chunk_index),
       txt_data = paste0(.SD$txt_data, collapse = ""),
       width = sum(.SD$width),
       height = max(.SD$ascent) + max(.SD$descent)
@@ -676,7 +717,7 @@ arrange_contents_grob <- function(x,
     if (do_update_grob) {
       children <- gList(make_col_grob(
         1L, dat$chunk_index,
-        dat$txt_data, dat$seq_index, dat$seq_index,
+        dat$txt_data, dat$.chunk_index, dat$.chunk_index,
         dat$width, dat$height
       ))
     }
